@@ -22,23 +22,18 @@
 #   checking this is a useful IP address.
 #
 
+require 'facter/util/ip'
+
 Facter.add(:ipaddress) do
   confine :kernel => :linux
   setcode do
     ip = nil
-    output = %x{/sbin/ifconfig 2>/dev/null}
-
-    output.split(/^\S/).each { |str|
-      if str =~ /inet addr:([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
-        tmp = $1
-        unless tmp =~ /^127\./
-          ip = tmp
-          break
-        end
+    if output = Facter::Util::IP.get_ifconfig
+      regexp = /inet (?:addr:)?([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
+      if match = regexp.match(output)
+        match[1] unless /^127/.match(match[1])
       end
-    }
-
-    ip
+    end
   end
 end
 
